"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const ArrayCollection_1 = require("./ArrayCollection");
const metadata_1 = require("../metadata");
class EntityTransformer {
    static toObject(entity, parent, isCollection = false) {
        const platform = entity.__em.getDriver().getPlatform();
        const pk = platform.getSerializedPrimaryKeyField(entity.__primaryKeyField);
        const ret = (entity.__primaryKey ? { [pk]: platform.normalizePrimaryKey(entity.__primaryKey) } : {});
        if (!entity.isInitialized() && entity.__primaryKey) {
            return ret;
        }
        Object.keys(entity)
            .filter(prop => prop !== entity.__primaryKeyField && !prop.startsWith('_'))
            .map(prop => [prop, EntityTransformer.processProperty(prop, entity, parent || entity, isCollection)])
            .filter(([, value]) => !!value)
            .forEach(([prop, value]) => ret[prop] = value);
        return ret;
    }
    static processProperty(prop, entity, parent, isCollection) {
        if (entity[prop] instanceof ArrayCollection_1.ArrayCollection) {
            return EntityTransformer.processCollection(prop, entity);
        }
        if (utils_1.Utils.isEntity(entity[prop])) {
            return EntityTransformer.processEntity(prop, entity, parent, isCollection);
        }
        return entity[prop];
    }
    static processEntity(prop, entity, parent, isCollection) {
        const child = entity[prop];
        const platform = child.__em.getDriver().getPlatform();
        if (child.isInitialized() && child.__populated && !isCollection && child !== parent) {
            const meta = metadata_1.MetadataStorage.getMetadata(child.constructor.name);
            const args = [...meta.toJsonParams.map(() => undefined), entity];
            return child.toJSON(...args);
        }
        return platform.normalizePrimaryKey(child.__primaryKey);
    }
    static processCollection(prop, entity) {
        const col = entity[prop];
        if (col.isInitialized(true) && col.shouldPopulate()) {
            return col.toArray(entity);
        }
        if (col.isInitialized()) {
            return col.getIdentifiers();
        }
    }
}
exports.EntityTransformer = EntityTransformer;
